@@ -1,4 +1,4 @@
-@defaults = ( [  2, 2 ], 1, 1, 7, 0.01, 0.99 );
+@defaults = ( [  2, 2 ], 1, 2, 2, 0.01, 0.99 );
 
 
 
@@ -21,18 +21,17 @@
 # A value of "1" means that if the new shading value is increased instead of decreased in place of the old one,
 # the change is not executed.
 
-$computype = "linear";
+$computype = "root";
 # TYPES OF CALCULATIONS FOR CALCULATING THE IRRADIANCE FACTORS.
 # (SEE SUBROUTINE "compareirrs".)
 # OPTIONS: "linear", "quadratic", "root".
 # THESE OPTIONS ARE ON THE WAY TO BE DISCARDED AND BECOME OBSOLETE. ONLY "linear will remain".
 # WHEN UNSPECIFIED, THE DEFAULT IS "linear".
 
-@calcprocedures = ( "complete", "diluted" );
-#@calcprocedures = ( "complete", "besides", "diluted", "extra" );
+@calcprocedures = ( "complete", "besides", "diluted", "extra" );
 # The options are the following:
 # "simplified", "incomplete", "basic", "main", "alternative", "complete", "spreaddiff", "diluted", "quadratic__", "sqroot__", "halved__", 
-# "conflated", "conflated__", "extra", "besides", "halved", "halved250", "halved125", "halved375".
+# "conflated", "conflated__", "extra", "besides", "halved", "halved250", "halved125", "halved375", "halved0625".
 # "main", "alternative", "complete" and "spreaddiff" can be combined with the other options. 
 # The others can't. "basic" also can be combined with the others: it can be used in place of "alternative".
 # "spreaddiff"c CAN'T BE USED ALONE.
@@ -46,7 +45,7 @@ $computype = "linear";
 # Both, can be used with $computype = "linear" or "root".
 # 
 
-%specularratios = ( reflector => 0, roughnval => 0.25 );
+%specularratios = ( reflector => 0, roughnval => 0.40, reflrat =>1, roughnroughval => 0.99, reflroughrat => 1 );
 #%specularratios = ( totaldirect => 1 );
 #%specularratios = ( reflector => 1 );
 # THE VALUE OF EACH OF THESE KEY-VALUE PAIRS CONSTITUTES THE PROPORTION OF THE SPECULAR REFLECTIVITY
@@ -59,8 +58,13 @@ $computype = "linear";
 # EXAMPLE: %specularratios = ( totaldirect => 1 );
 # (SEE SUBROUTINE "pursue").
 # IF IN @calcprocedures "besides" is present, in %specularratios a roughness value 
-# between 0 and 1 must be spefied as "roughnval". EXAMPLE:
-# %specularratios = ( roughnval => 0.25 );
+# between 0 and 1 must be spefied as "roughnval" . the roughness value of reflectors.
+# "roughnroughval" is the roughness value of the non-reflectors. 
+# "roughnroughval" is the roughness value of the non-reflectors. 
+# "reflrat" is the ratio of diffuse to specular reflectivity of reflectors.
+# As an alternative, the reflectivity of reflectors can specified as "reflval", a value of reflectivity, non a ratio.
+# "reflroughrat" is the ratio of diffuse to specular reflectivity of non-reflectors.
+# As an alternative, the reflectivity of non-reflectors can specified as "reflroughval", a value of reflectivity, not a ratio.
 
 %skycondition = ( 1=> "clear", 2=> "clear", 3=> "clear", 4=> "clear", 5=> "clear", 6=> "clear", 7=> "clear", 8=> "clear", 
 	9=> "clear", 10=> "clear", 11=> "clear", 12=> "clear" );
